@@ -3,8 +3,8 @@ from typing import List
 
 import pycron
 
-from git_syncer.jobs.models import CronJob
-from git_syncer.utils.logger import wrap
+from .models import CronJob
+from ..utils.logger import wrap
 
 log = logging.getLogger(__name__)
 
@@ -12,13 +12,13 @@ CRON_JOBS: List[CronJob] = []
 
 
 def run_crons():
-    log.info("Running cron jobs.")
+    log.info(f"Checking {wrap(len(CRON_JOBS))} cron jobs.")
     for job in CRON_JOBS:
         if pycron.is_now(job.expression):
             log.debug(f"Running cron {wrap(job.name)}")
             try:
                 job.run()
-            except:
+            except:  # noqa
                 log.exception("Job execution failed")
 
 
